# Contributing to LibRapid

Feel free to contribute to LibRapid in any way you see fit. This could be by opening an issue,
answering questions or helping development on our [Discord Server](https://discord.gg/cGxTFTgCAC),
or by submitting your own pull requests -- any help is very welcome!

## Contribution Rules

When contributing to LibRapid, you ***must*** follow
the [Code of Conduct](https://github.com/LibRapid/librapid/blob/master/CODE_OF_CONDUCT.md),
otherwise your contributions and any credit may be removed!

## Sponsorships

LibRapid is a free and open source project, and will always be. However, if you would like to support the project
financially, you can do so by sponsoring the project on [GitHub](https://github.com/sponsors/Pencilcaseman).

We are also looking for powerful hosted servers to enable us to run better tests and benchmarks to accelerate
development. If you are part of a company that provides such services, please contact us on
our [Discord Server](https://discord.gg/cGxTFTgCAC).
